"estimate" <-
function(Y, Time, N, K, iter, ...){

# Function estimate
# required arguments:
# Y: N x K matrix of responses (0/1 for incorrect/correct, 9 for missing data)
# Time: N x K matrix containing log-response times
# N: number of persons
# K: number of items
# iter: number of iterations
#
# optional arguments:
# PL: PL = 1 restricts the response model to the Rasch model. PL =2 fits
# the 2PL model and is the default value.
# index: index = 1 restricts var(zeta) = 1. 
# Specifying $index =1$ is helpful when the data is such that identification of the model is weak.
# output is a list containing 38 items:
# a is stored in item 22
# b is stored in item 23
# phi is stored in item 24
# lambda is stored in item 25
# theta is stored in item 26
# zeta is stored in item 27
# mu_I is stored in item 28
# sigma_Iis stored in item 29
# sigma_Pis stored in item 30
# D(hat)is stored in item 33
# D(bar)is stored in item 34
# pdis stored in item 35
# DIC is stored in item 36
# p(log(t_ik* < log(t_ik)) is stored in item 37
# PHI(y_ik | y, t) is stored in item 38
# The log-likelihoods of the response model and the response time model 
# are stored in item 31 and item 32 respectively
# 

if(length(Y) != N*K){stop("Dimension of item response matrix Y does not equal N x K")}
if(length(Time) != N*K){stop("Dimension of response time matrix Time does not equal N x K")}




dots <- list(...) 

if(hasArg(PL)){  PL <- dots$PL   }
else  {   PL <- 2  }                                                               
if(hasArg(index)){  PL <- dots$index   }
else  {   index <- 0  }                                                               

mu0 <- matrix(0, nrow=2, ncol=K)
mu0[1,] <- 1
sigma0 <- matrix(0, ncol =2, nrow=2)
sigma0[1,1] <- sigma0[2,2] <-  20

## IRT variables
alpha1 <- runif(K, 0.9,1.1)
beta1 <- rnorm(K, sd = 0.5)
theta <- rnorm(N)

## RT variables
alpha2 <- runif(K, 1,2)
beta2 <- rnorm(K, 5,1)
tau <- rnorm(N, 0,1)


# Item parameters
kappaI0 <- 4
NuI0 <- 4
MuI0<- c(1,0,1,5)
SigmaI0 <- matrix(c(10,1,1,1,1,10,1,1,1,1,10,1,1,1,1,10), ncol =4, nrow =4)
muI <- c(1,0,1,5)
sigmaI <- matrix(c(1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1), ncol =4, nrow =4)
COV <- matrix(c(1,0,0,1), ncol =2, nrow =2)

# Person parameters
kappaP0 <- 2
NuP0 <- 2
muP0 <- c(0,0)
sigmaP0 <- matrix(c(1,0,0,1), ncol =2, nrow =2)
muP <- c(0,0)
sigmaP <- matrix(c(1,0,0,1), ncol =2, nrow =2)

SMH1 <- 0.05
SMH2 <- 0.05

# Storage variables
Mtheta <- matrix(0,ncol = N, nrow = 1)
Mtau <- matrix(0,ncol = N, nrow = 1)
Mbeta1 <- matrix(0, ncol = K, nrow =iter)
Mbeta2 <- matrix(0, ncol = K, nrow =iter)
Malpha2 <- matrix(0, ncol = K, nrow =iter)
Malpha1 <- matrix(0, ncol = K, nrow =iter)
SmuI <- matrix(0, ncol =4, nrow =iter)
SsigmaI <- matrix(0, ncol = 16, nrow= iter)
SsigmaP <- matrix(0, ncol =4, nrow = iter)
Stheta <- matrix(0, ncol = N, nrow = iter)
Sgamma <- matrix(0, nrow=iter, ncol = 6)
LOGLIKY <- rep(0, iter)
LOGLIKT <- rep(0, iter)
DHAT <- 0
DBAR <- 0
PD <- 0
DIC <- 0
PCY <- matrix(0, ncol = K, nrow = N)
PCT <- matrix(0, ncol = K, nrow = N)


out <- .Fortran("IRTRT", as.integer(N),as.integer(K), as.integer(index), as.integer(PL), as.integer(iter), as.double(Y), as.double(Time), 
 as.integer(NuI0), as.double(SigmaI0), as.double(COV), as.double(SMH1), as.double(SMH2),
 as.double(muI), as.double(sigmaP),as.double(sigmaI), as.double(alpha1), as.double(beta1), 
 as.double(alpha2), as.double(beta2), as.double(tau), as.double(theta), as.double(Malpha1), as.double(Mbeta1),
 as.double(Malpha2), as.double(Mbeta2), as.double(Mtheta), as.double(Mtau), as.double(SmuI), 
as.double(SsigmaI),  as.double(SsigmaP), as.double(LOGLIKY), as.double(LOGLIKT), 
as.double(DHAT), as.double(DBAR), as.double(PD), as.double(DIC), as.double(PCY), as.double(PCT)) 

return(out)
}

