"generate" <-
function(N, K,...){

## Function simulate generates data for the CIRT program
## Note that you should load the MASS package in order to be able to use "mvrnorm"
## output is a list of length 8
## Y is stored in data$Y
## Time is stored in data$Time
## use: data <- simulate(N,K), Y <- data$Y, time <- data$Time


if(hasArg(rho)){  ctz <- dots$rho   }
else  {   ctz <- .5 }  
if(hasArg(corbl)){  cbl <- dots$corbl   }
else  {   cbl <- .3 }  
mut <- 0
muz <- 0
X <- mvrnorm(N, mu = c(mut,muz), Sigma = matrix(c(1,ctz,ctz,1), 2))
theta <- X[,1]
zeta  <- X[,2]

mua = 1
mub = 0
mup = 1
mul = 0
cap = 0
va = .1
vb = 1
vp = .1
vl = 1

X <- mvrnorm(K, mu = c(mua,mub,mup,mul), Sigma = matrix(c(va,0,cap,0,0,vb,0,cbl,cap, 0, vp,0,0,cbl,0,vl), 4))
alpha  <- X[,1]
beta   <- X[,2]
phi    <- X[,3]
lambda <- X[,4]

## IRT variables
guess <- rep(0, K)
Y <- matrix(0,ncol=K,nrow=N)
Y <- matrix(unlist(lapply(1:K,function(kk,alpha,beta,guess, theta,N) { 
 ifelse(runif(N,0,1) < (guess[kk]+(1-guess[kk])*pnorm(alpha[kk]*theta[1:N]-beta[kk])),1,0)},theta=theta,alpha=alpha,beta=beta,guess=guess,N=N)),ncol=K,nrow=N)

## RT variables
time <- matrix(rnorm(N*K), nrow= K, ncol =N) 
time[1:K,] <- time[1:K,]/phi[1:K] + lambda[1:K]
for (i in 1:K) {time[i,1:N] <- time[i,1:N] - zeta[1:N] }
time <- t(time)

data <- new.env()
data$alpha <- alpha
data$beta <- beta
data$phi <- phi
data$lambda <- lambda
data$zeta <- zeta
data$theta <- theta
data$Y <- Y
data$Time <- time
data <- as.list(data)

return(data)
}

