"summarize" <-
function(out, burnin){

# function summarize
# required arguments: 
#out: list which contains the estimates generated by the function estimate.
#burnin: number of iterations to be discarded as the burn in period of
#the MCMC chain.
# output is a report with a summary of the parameter estimates and a DIC - fit measure.

if(burnin >= out[[5]]){stop("Burnin cannot exceed the number of iterations! Please choose a
smaller burnin period for the MCMC chain, or type ?summarize for more information.")}


# 
#  print numeric values in fixed point format, with 
# w = field width
# d = # of decimal places
#
#  If matrix = T, print as a matrix or a column vector.
#  Does not handle row names or column names.
#
printF <- function(x, w, d, matrix = F){
if(matrix)
x <- as.matrix(x)
if(!is.numeric(x))
stop("x must be numeric in printF")
if(length(x) == 1) {
cat(formatF(x, w = w, d = d))
}
else if(!matrix) {
cat(formatF(as.vector(x), w = w, d = d))
}
else {
apply(as.matrix(x), 1, FUN = function(y, w, d)
{
cat(formatF(y, w = w, d = d))
}
, w = w, d = d)
}
invisible()
}

formatF <- function(x, w, d){

#
# Format x as a Fixed Point number with fixed-width w and d places to the 
#  right of the decimal pt. If the number is too wide to fit, fill
#  the field with '*'s.  If d=0, do not print the decimal point.
#  Pad left with blanks. Pad right with zeros.
#
#  x can be a vector.  All elements of the vector will be formatted
#   the same. x cannot be a matrix or data frame.
#
wholePart <- as.integer(x)
wholeStrings <- as.character(wholePart)
wholeStrings <- ifelse((wholeStrings == 0) & (x < 0), paste("-", 
wholeStrings, sep = ""), wholeStrings)
wholeWidths <- ifelse(d > 0, w - d - 1, w)
leftPad <- wholeWidths - nchar(wholeStrings)
decimalPart <- round(x - wholePart, digits = d)
decimalStrings <- as.character(decimalPart)
decimalStrings <- substring(decimalStrings, regexpr("\\.", 
decimalStrings) + 1)
rightPad <- ifelse(rep(d, length(x)) > 0, d - nchar(decimalStrings),
0)
for(i in seq(along = wholeStrings)) {
if(leftPad[i] >= 0) {
wholeStrings[i] <- paste(paste(rep(" ", leftPad[i]),
collapse = ""), wholeStrings[i], sep = "")
}
else {
wholeStrings[i] <- paste(rep("*", wholeWidths[i]),
collapse = "")
}
if(rightPad[i] > 0) {
decimalStrings[i] <- paste(decimalStrings[i], paste(
rep("0", rightPad[i]), collapse = ""), sep = 
"")
}
}
decimalPoint <- ifelse(d > 0, ".", "")
if(d > 0)
paste(wholeStrings, decimalPoint, decimalStrings, sep = "")
else paste(wholeStrings)
}


bb <- burnin +1
N <- out[[1]]
K <- out[[2]]
iter <- out[[5]]

cat("\n", "CIRT Version 1.0 August 2006, R.H. Klein Entink, Twente University")
cat("\n", "Summary of the results of the CIRT program")

cat("\n\n\t", "Discrimination parameter", "\t\t", "Difficulty parameter", "\n")
cat("\t", "item", "\t", "EAP", "\t", "s.d ", "\t\t\t","item", "\t", "EAP", "\t", "s.d ")
alpha <- matrix(out[[22]], ncol = K, nrow = iter)
malpha <- colMeans(alpha[bb:iter,])
sdalpha <- apply(alpha[bb:iter,],2,sd)
beta <- matrix(out[[23]], ncol = K, nrow = iter)
mbeta <- colMeans(beta[bb:iter,])
sdbeta <- apply(beta[bb:iter,],2,sd)
for(ii in 1:K){
cat("\n\t", ii,"\t") 
printF(malpha[ii],w=5 ,d = 2) 
cat("\t")
printF(sdalpha[ii],w=5, d=2)
cat("\t\t\t",ii,"\t")
printF(mbeta[ii], w=5,d=2)
cat("\t") 
printF(sdbeta[ii], w=5, d=2)
}

cat("\n\n\t", "Time Discriminationparameter", "\t", "Time intensity parameter", "\n")
cat("\t", "item", "\t", "EAP", "\t", "s.d ", "\t\t\t","item", "\t", "EAP", "\t", "s.d ")
alpha <- matrix(out[[24]], ncol = K, nrow = iter)
malpha <- colMeans(alpha[bb:iter,])
sdalpha <- apply(alpha[bb:iter,],2,sd)
beta <- matrix(out[[25]], ncol = K, nrow = iter)
mbeta <- colMeans(beta[bb:iter,])
sdbeta <- apply(beta[bb:iter,],2,sd)
for(ii in 1:K){
cat("\n\t", ii,"\t") 
printF(malpha[ii], w=5, d= 2) 
cat("\t")
printF(sdalpha[ii],w=5, d=2)
cat("\t\t\t",ii,"\t")
printF(mbeta[ii], w=5,d=2)
cat("\t") 
printF(sdbeta[ii], w=5, d=2)
}

sigmaI <- matrix(colMeans(matrix(out[[29]], ncol =16, nrow= iter)[bb:iter,]), ncol =4, nrow =4)
cat("\n\n\t", "Covariance matrix item parameters", "\n\n")
cat("\t","a","\t","b", "\t", "phi", "\t", "lambda")
for(ii in 1:4){
cat("\n\t")
for(jj in 1:4){
printF(sigmaI[ii,jj], w=5,d=2)
cat("\t")
}
}
sigmaP <- matrix(colMeans(matrix(out[[30]], ncol =4, nrow= iter)[bb:iter,]), ncol =2, nrow =2)
cat("\n\n\t", "Covariance matrix person parameters", "\n\n")
cat("\t","theta","zeta")
for(ii in 1:2){
cat("\n\t")
for(jj in 1:2){
printF(sigmaP[ii,jj], w=5,d=2)
cat("\t")
}
}
cat("\n\n")
cat("\t", "DIC", "\t")
printF(out[[36]],w =10, d =2)
cat("\n\n")
}

