\name{cirt-package}
\alias{cirt-package}
\alias{cirt}
\docType{package}
\title{
Conjoint IRT modeling of Responses and Response Times
}
\description{
In computerized testing, the test takers' responses as well as their response times on
the items are recorded. The relationship between response times and response accuracies is
complex and varies over levels of observation. For example, it takes the form of a tradeoff between speed and accuracy at the level of a fixed person but may become a possitive correlation for a population of test takers. In order to explore such relationships and
test hypotheses about them, a conjoint model is proposed. Item responses
are modeled by a two-parameter normal-ogive IRT model and response times by a lognormal
model. The two models are combined using a hierarchical framework based on the fact that response
times and responses are nested within individuals. All parameters can be estimated simultaneously
using a Markov Chain Monte Carlo estimation approach.

This package allows for simultaneous estimation of the response and response time model on test data. 
It contains a function for data generation, one for estimation of the hierarchical modeling framework and
a function for analysis of the estimation results. 
Thereby this package allows also for several analysis of dependencies between responses and response times.
For further details, see the reference below. Also, an example is specified below which shows how to use this package.

}
\details{
\tabular{ll}{
Package: \tab cirt\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2007-01-09\cr
License: \tab GPL -2\cr
}
The package has three functions: 
- "Generate" for generating data. This function simulates test data: responses, correct
or incorrect answers of test takers to items and a matrix of the log-response times for each person - item combination.
- "estimate" for fitting the model to the data.
- "summarize" which gives a summary of the results of estimate. 
}
\author{
R.H. Klein Entink

Maintainer: <r.h.kleinentink@gw.utwente.nl>
R.H. Klein Entink (Rinke)
}
\references{
 J.-P. Fox, R.H. Klein Entink, W.J. van der Linden, Modeling of responses and response times with the package CIRT, Journal of Statistical Software }

}
\examples{
Use the functions in the following way. Please note that 1,000 iterations can take up a few minutes!! 
Note also that for 'real-life' analysis, the number of iterations should be larger, as well as burnin, depending on
the quality of the data. 
 
N <- 500					# 500 test takers
K <- 20						# taking 20 items
data <- generate(N,K) 				# Generate data
iter <- 1000					# 1,000 iterations of the Gibbs sampler
out <- estimate(data$Y, data$Time, N, K, iter) 	# fitting the model
burnin <- 100					# specify burn-in period of MCMC chain
summarize(out, burnin)	    			# analysis of the MCMC chains
}
