\name{estimate}
\alias{estimate}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Estimate}
\description{
  Estimate calls a Fortan programm (IRTRT.dll) which estimates the 2PL normal ogive IRT model on the 
  test data 'Y' and a log-normal model on the response times 'Time'. A multivariate covariance structure
is estimated for the person parameters as well as the item parameters of both models.

}
\usage{
estimate(Y, Time, N, K, iter, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{Y}{ N x K matrix of item responses (0/1 for incorrect/correct, 9 for missing data. Missing data are always assumed to be missing by
design; the estimates are based on the observed data only, no imputation method is used.) }
  \item{Time}{ N x K matrix containing log-response times }
  \item{N}{ number of persons }
  \item{K}{ number of items }
  \item{iter}{desired number of iterations }
  \item{\dots}{ Optional arguments: PL: PL = 1 restricts the item response model to the Rasch model. PL =2 fits
the 2PL item response model and is the default value.

index: index = 1 restricts var(zeta) = 1. 
Specifying $index =1$ is helpful when the data is such that identification of the model is weak. }
}

\details{
  Estimate is part of the CIRT package, see also the function 'generate' for data generation and
 the function 'summarize' for summarizing the output of 'estimate'.
Type "?cirt" for a worked out example how to use the package. 

Please note that a sufficient amount of iterations should be specified for the Gibbs sampler to obtain convergence of the MCMC chain.
A few thousand iterations is recommended and convergence of the MCMC chain should always be checked to determine the burnin period for "summarize".
 
}


\value{
Starting values are generated automatically. The output consists of a list
containing the sampled values from the marginal
posterior distributions of all model parameters and some of the model-fit criteria.
For details of the items specifies below, see the reference article. 

  Output is a list which contains:

  \item{a}{The discimination parameters of the IRT model are stored in item 22}
  \item{b}{Difficulty parameters are stored in item 23}
  \item{phi}{Discrimination parameter (response time model) stored in item 24}
  \item{lambda}{item time intensity parameters stored in item 25}
  \item{theta}{ability parameters of the test takers, stored in item 26}
  \item{zeta}{speed parameters of the test takers, stored in item 27}
  \item{mu_I}{stored in item 28}
  \item{sigma_I}{Covariance matrix item parameters, stored in item 29}
  \item{sigma_P}{Covariance matrix person parameters, stored in item 30}
  \item{D(hat)}{stored in item 33}
  \item{D(bar)}{stored in item 34}
  \item{pd}{# effective model parameters, stored in item 35}
  \item{DIC}{Model fit criterium, is stored in item 36}
  \item{p(log(t_ik* < log(t_ik))}{ is stored in item 37}
  \item{PHI(y_ik | y, t)}{ is stored in item 38}
  \item{Log-Lik}{The log-likelihoods of the response model and the response time model 
	are stored in item 31 and item 32 respectively}
  
}
\references{  J.-P. Fox, R.H. Klein Entink, W.J. van der Linden, Modeling of response times and patterns: With a package CIRT, Journal of Statistical Software }
\author{ R.H. Klein Entink (Rinke) <r.h.kleinentink@gw.utwente.nl> }

\examples{

## Estimate the model to a data set using 5,000 iterations:
iter <- 5000
out <- estimate(data$Y, data$Time, N, K, iter)

## Estimate the model to a data set using 5,000 iterations, restricting the IRT model to the Rasch model:
iter <- 5000
out <- estimate(data$Y, data$Time, N, K, iter, 'PL = 1')

  
}
\keyword{ IRT }% at least one, from doc/KEYWORDS
\keyword{  }% __ONLY ONE__ keyword per line
